realdentalcosts.api

Zero-dependency Clojure client for the Real Dental Costs Open Data API (https://realdentalcosts.com/en/api/): US dental procedure cash price ranges by state, state cost indexes and Medicaid paid amounts per CDT code (HHS/CMS T-MSIS). Data CC BY 4.0. Uses only java.net.http and clojure.data.json if present; otherwise returns raw JSON strings.

Zero-dependency Clojure client for the Real Dental Costs Open Data API
(https://realdentalcosts.com/en/api/): US dental procedure cash price
ranges by state, state cost indexes and Medicaid paid amounts per CDT code
(HHS/CMS T-MSIS). Data CC BY 4.0. Uses only java.net.http and clojure.data.json
if present; otherwise returns raw JSON strings.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries